# Changelog
All notable changes to this project will be documented in this file.

## Power-events

## 1.2.0 (2025-11-10)

### :wrench: configuration

- support python 3.14

## 1.1.0 (2024-12-12)

### :recycle: Refactoring

- ValuePath use `get_from` instead of `get`

### :sparkles: Features

- add fallback route
- add exception handling

## 1.0.0 (2024-11-24)

### :sparkles: Features

- change ValuePath
- raise error when value missing
- allow equals at None
- add resolver
- add conditions
